@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #ifndef _M17N_FONT_H_
 #define _M17N_FONT_H_
@@ -155,7 +155,7 @@ struct MRealizedFont
      carry the infomation.  */
   MSymbol layouter;
 
-  /* 1 iff the font is opend by encapsulating client-side font data.  */
+  /* 1 if the font is opend by encapsulating client-side font data.  */
   int encapsulating;
 
   /* Extra information set by MRealizedFont::driver->open.  If
