@@ -1,5 +1,5 @@
 /* language.c -- language (and script) module.
-   Copyright (C) 2003, 2004, 2006
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #include <config.h>
 #include <stdlib.h>
@@ -317,11 +317,21 @@ mscript__from_otf_tag (MSymbol otf_tag)
 	  && (p = MPLIST_NEXT (p)) /* char list */
 	  && ! MPLIST_TAIL_P (p)
 	  && (p = MPLIST_NEXT (p)) /* otf tag */
-	  && MPLIST_SYMBOL_P (p)
-	  && otf_tag == MPLIST_SYMBOL (p))
+	  && ! MPLIST_TAIL_P (p))
 	{
-	  script = MPLIST_SYMBOL (pl);
-	  break;
+	  if (MPLIST_SYMBOL_P (p))
+	    {
+	      if (otf_tag == MPLIST_SYMBOL (p))
+		  return MPLIST_SYMBOL (pl);
+	    }
+	  else if (MPLIST_PLIST (p))
+	    {
+	      MPlist *p0;
+
+	      MPLIST_DO (p0, MPLIST_PLIST (p))
+		if (MPLIST_SYMBOL_P (p0) && otf_tag == MPLIST_SYMBOL (p0))
+		  return MPLIST_SYMBOL (pl);
+	    }
 	}
     }
   return script;
@@ -332,6 +342,11 @@ mscript__from_otf_tag (MSymbol otf_tag)
 
 /* External API */
 
+/*** @addtogroup m17nLocale */
+/*** @{ */
+/*=*/
+
+
 MSymbol Miso639_1, Miso639_2;
 
 /*=*/
@@ -351,15 +366,15 @@ MSymbol Miso639_1, Miso639_2;
     mscript_list ().  */
 
 /***ja
-    @brief 3ʸ쥳ɤꥹȤ.
+    @brief 3文字言語コードをリストする.
 
-    ؿ mlanguage_list () ϡ (well-formed) plist ֤ƥ
-     #Msymbol Ǥꡢġͤ ISO639-2 줿3ʸ쥳
-    ɤ̾Ȥ륷ܥǤ롣
+    関数 mlanguage_list () は、整形式 (well-formed) plist を返す。各キー
+    は #Msymbol であり、個々の値は ISO639-2 に定められた3文字言語コー
+    ドを名前とするシンボルである。
 
     @return
-    δؿ֤ plist ϡƤӽФ¦ m17n_object_unref () Ȥ
-    Ʋɬפ롣
+    この関数が返す plist は、呼び出し側が m17n_object_unref () を使っ
+    て解放する必要がある。
 
     @seealso
     mscript_list ().  */
@@ -405,22 +420,22 @@ mlanguage_list (void)
     mlanguage_name_list (), mlanguage_text ().  */
 
 /***ja
-    @brief 쥳ɤ.
+    @brief 言語コードを得る.
 
-    ؿ mlanguage_code () ϡ$LANGUAGE б ISO-639 쥳
-    ̾Ǥ褦ʥܥ֤$LANGUAGE ϥܥǤꡢ
-    ̾ϡISO639-2 3ʸ쥳ɡISO639-1 2ʸ쥳ɡѸ̾
-    Τ줫Ǥ롣
+    関数 mlanguage_code () は、$LANGUAGE に対応した ISO-639 言語コード
+    が名前であるようなシンボルを返す。$LANGUAGE はシンボルであり、その
+    名前は、ISO639-2 3文字言語コード、ISO639-1 2文字言語コード、英語名、
+    のいずれかである。
 
-    $LEN ֤쥳ɤμꤹ롣$LEN 3ξ 
-    ISO639-2 3ʸ쥳ɤ֤롣2ξϡ⤷Ƥ
-     ISO639-1 2ʸ쥳ɤǤʤ #Mnil ֤롣0 
-    ξϡ⤷Ƥ2ʸɤǤʤ3ʸ
-    ɤ֤롣
+    $LEN は返される言語コードの種類を決定する。$LEN が3の場合は 
+    ISO639-2 3文字言語コードが返される。2の場合は、もし定義されていれ
+    ば ISO639-1 2文字言語コードが、そうでなければ #Mnil が返される。0 
+    の場合は、もし定義されていれば2文字コードが、そうでなければ3文字コー
+    ドが返される。
 
     @return
-    ⤷Сδؿ #Mnil ʳΥܥ֤
-    Ǥʤ #Mnil ֤
+    もし情報が得られれば、この関数は #Mnil 以外のシンボルを返す。そう
+    でなければ #Mnil を返す。
 
     @seealso
     mlanguage_name (), mlanguage_text ().  */
@@ -620,16 +635,16 @@ mlanguage_name_list (MSymbol language, MSymbol target,
     mlanguage_code (), mlanguage_name ().  */
 
 /***ja
-    @brief Ϳ줿켫Ȥǽ񤫤줿֤̾.
+    @brief 与えられた言語自身で書かれた言語名を返す.
 
-    ؿ mlanguage_text () ϡ $LANGUAGE ǽ񤫤줿 $LANGUAGE 
-    ̾ M-text η֤θɽŪʸ狼äƤ
-    ϡ֤ M-text γʸˡ #Mtext ͤɽŪ
-    ʸޤ M-text Ǥ褦ʥƥȥץѥƥղä롣
+    関数 mlanguage_text () は、言語 $LANGUAGE で書かれた $LANGUAGE の
+    名前を M-text の形式で返す。その言語の代表的な文字がわかっている場
+    合は、返される M-text の各文字に、キーが #Mtext で値がその代表的な
+    文字を含む M-text であるようなテキストプロパティが付加される。
 
     @return
-    줿硢δؿ֤ M-text ѹ
-    ꤷƤϤʤʤä @c NULL ֤롣
+    求める情報が得られた場合、この関数が返す M-text を変更したり解放し
+    たりしてはいけない。情報が得られなかった場合は @c NULL が返される。
 
     @seealso
     mlanguage_code (), mlanguage_name ().  */
@@ -676,15 +691,15 @@ mlanguage_text (MSymbol language)
     mscript_language_list (), mlanguage_list ().  */
 
 /***ja
-    @brief ץ̾ꥹȤ.
+    @brief スクリプト名をリストする.
 
-    ؿ mscript_list () ϡ (well-formed) plist ֤ƥ
-     #Msymbol Ǥꡢġͤϥץ̾̾Ȥ륷ܥǤ
-    롣
+    関数 mscript_list () は、整形式 (well-formed) plist を返す。各キー
+    は #Msymbol であり、個々の値はスクリプト名を名前とするシンボルであ
+    る。
 
     @return
-    δؿ֤ plist ϡƤӽФ¦ m17n_object_unref () Ȥ
-    Ʋɬפ롣
+    この関数が返す plist は、呼び出し側が m17n_object_unref () を使っ
+    て解放する必要がある。
 
     @seealso
     mscript_language_list (), mlanguage_list ().  */
@@ -728,18 +743,18 @@ mscript_list (void)
     mscript_list (), mlanguage_list ().  */
 
 /***ja
-    @brief Ϳ줿ץȤѤꥹȤ.
+    @brief 与えられたスクリプトを用いる言語をリストする.
 
-    ؿ mscript_language_list () ϡ$SCRIPT ѤꥹȤ롣
-    $SCRIPT ϥܥǡ̾ Unicode Character Database ˼
-    Ƥ륹ץ̾򤹤٤ƾʸˤΤǤ롣
+    関数 mscript_language_list () は、$SCRIPT を用いる言語をリストする。
+    $SCRIPT はシンボルで、その名前は Unicode Character Database に示さ
+    れているスクリプト名をすべて小文字にしたものである。
 
     @return 
-    δؿϡ (well-formed) plist ֤ƥ 
-    #Msymbol Ǥꡢġͤ ISO639-1 줿2ʸ쥳
-    (Ƥʤ ISO639-2 줿3ʸ쥳) ̾
-    Ȥ륷ܥǤ롣֤ plist ѹꤷ
-    Ϥʤʤ$SCRIPT ̤Τξ @c NULL ֤롣
+    この関数は、整形式 (well-formed) plist を返す。各キーは 
+    #Msymbol であり、個々の値は ISO639-1 に定められた2文字言語コード
+    (定義されていない場合は ISO639-2 に定められた3文字言語コード) を名
+    前とするシンボルである。返される plist は変更したり解放したりして
+    はならない。$SCRIPT が未知の場合は @c NULL が返される。
 
     @seealso
     mscript_list (), mlanguage_list ().  */
@@ -763,7 +778,7 @@ mscript_language_list (MSymbol script)
     @name Obsolete functions
 */
 /***ja
-    @name Obsolete ʴؿ
+    @name Obsolete な関数
 */
 /*** @{ */
 
@@ -785,15 +800,15 @@ mscript_language_list (MSymbol script)
     mlanguage_code (), mlanguage_text ().  */
 
 /***ja
-    @brief αѸ̾.
+    @brief 言語の英語名を得る.
 
-    ؿ mlanguage_name () ϡ$LANGUAGE αѸ̾̾Ȥ褦ʥ
-    ܥ֤$LANGUAGE ϥܥǤꡢ̾ϡISO639-2 3ʸ
-    쥳ɡISO639-1 2ʸ쥳ɡѸ̾Τ줫Ǥ롣
+    関数 mlanguage_name () は、$LANGUAGE の英語名を名前とするようなシ
+    ンボルを返す。$LANGUAGE はシンボルであり、その名前は、ISO639-2 3文
+    字言語コード、ISO639-1 2文字言語コード、英語名、のいずれかである。
 
     @return
-    Ƥʤ顢δؿ #Mnil ʳΥܥ
-    Ǥʤ #Mnil ֤
+    求めている情報が得られるなら、この関数は #Mnil 以外のシンボルを返
+    す。そうでなければ #Mnil を返す。
 
     @seealso
     mlanguage_code (), mlanguage_text ().  */
@@ -821,9 +836,10 @@ mlanguage_name (MSymbol language)
 }
 
 /*=*/
+/*** @} */
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
