@@ -48,28 +48,28 @@
     managed @e object.  See @ref m17nObject for the detail.
 */
 /***ja
-    @addtogroup m17nSymbol ܥ
+    @addtogroup m17nSymbol シンボル
 
-    @brief ܥ륪֥ȤȤ˴ؤ API.
+    @brief シンボルオブジェクトとそれに関する API.
 
-    m17n 饤֥ϰդ˷ޤ뼱̻ҤȤ @e ܥ 
-    ȸƤ֥֥ȤѤ롣ܥ X 饤֥ΥȥȻƤ뤬
-    0 İʾ @e ܥץѥƥ ĤȤǤ롣ܥץѥƥ
-    @e   @e  ʤ롣Ϥ켫ΥܥǤꡢͤ 
-    <tt>(void *)</tt> ˥㥹ȤǤΤʤ鲿Ǥ褤֥ܥ 
-    S ĥܥץѥƥΤ K ΤΡפñˡS  K 
-    ץѥƥפȸƤ֤Ȥ롣
+    m17n ライブラリは一意に決まる識別子として @e シンボル 
+    と呼ぶオブジェクトを用いる。シンボルは X ライブラリのアトムと似ているが、
+    0 個以上の @e シンボルプロパティ を持つことができる。シンボルプロパティは
+    @e キー と @e 値 からなる。キーはそれ自体シンボルであり、値は 
+    <tt>(void *)</tt> 型にキャストできるものなら何でもよい。「シンボル 
+    S が持つシンボルプロパティのうちキーが K のもの」を簡単に「S の K 
+    プロパティ」と呼ぶことがある。
 
-    ܥӤϼ˰ʲ3̤Ǥ롣
+    シンボルの用途は主に以下の3通りである。
 
-    @li ܥץѥƥ¾ΥץѥƥΥɽ
+    @li シンボルプロパティおよび他のプロパティのキーを表す。
 
-    @li ʸåȡɷϡեȥåȤʤɤγƼ索֥Ȥɽ
+    @li 文字セット、コード系、フォントセットなどの各種オブジェクトを表す。
 
-    @li m17n 饤֥ؿΰȤʤꡢؿεư椹롣
+    @li m17n ライブラリ関数の引数となり、関数の挙動を制御する。
 
-    @e  ȸƤФ̤ʥܥ뤬ꡢ򥭡Ȥƻĥץѥƥͤ
-    @e ֥ ǤʤƤϤʤʤܺ٤ @ref m17nObject ȡ
+    @e 管理キー と呼ばれる特別なシンボルがあり、管理キーをキーとして持つプロパティの値は
+    @e 管理下オブジェクト でなくてはならない。詳細は @ref m17nObject 参照。
 */
 
 /*=*/
@@ -302,12 +302,12 @@ MTextPropDeserializeFunc msymbol__deserializer = deserialize_symbol;
     represents @e false or @e no.  When coerced to "int", its value is
     zero.  #Mnil can't have any symbol property.  */
 /***ja
-    @brief "nil" ̾Ȥƻĥܥ.
+    @brief "nil" を名前として持つシンボル.
 
-    ܥ #Mnil  <tt>"nil"</tt> 
-    Ȥ̤̾ˡֵפޤϡפ̣롣
-    "int" Ѵ줿硢ͤ 0 Ǥ롣
-    #Mnil ȤϤʤ륷ܥץѥƥʤ  */
+    シンボル #Mnil は <tt>"nil"</tt> 
+    という名前を持ち、一般に「偽」または「否定」を意味する。
+    "int" に変換された場合、値は 0 である。
+    #Mnil 自身はいかなるシンボルプロパティも持たない。  */
 
 MSymbol Mnil;
 
@@ -319,9 +319,9 @@ MSymbol Mnil;
     The symbol #Mt has the name <tt>"t"</tt> and, in general,
     represents @e true or @e yes.  */
 /***ja
-    @brief "t" ̾Ȥƻĥܥ.
+    @brief "t" を名前として持つシンボル.
 
-    ܥ #Mt  <tt>"t"</tt> Ȥ̤̾ˡֿפޤϡֹפ̣롣  */
+    シンボル #Mt は <tt>"t"</tt> という名前を持ち、一般に「真」または「肯定」を意味する。  */
 
 MSymbol Mt;
 
@@ -334,10 +334,10 @@ MSymbol Mt;
     as an argument of the functions mchar_define_property (),
     etc.  */
 /***ja
-    @brief "string" ̾Ȥƻĥܥ.
+    @brief "string" を名前として持つシンボル.
 
-    ܥ #Mstring  <tt>"string"</tt> Ȥ̾ؿ 
-    mchar_define_property () ʤɤΰȤѤ롣  */
+    シンボル #Mstring は <tt>"string"</tt> という名前を持ち、関数 
+    mchar_define_property () などの引数として用いられる。  */
 
 MSymbol Mstring;
 
@@ -350,10 +350,10 @@ MSymbol Mstring;
     as an argument of the functions mchar_define_property (),
     etc.  */
 /***ja
-    @brief "symbol" ̾Ȥƻĥܥ.
+    @brief "symbol" を名前として持つシンボル.
 
-    Ѥߥܥ #Msymbol  <tt>"symbol"</tt> Ȥ̾ؿ
-    mchar_define_property () ʤɤΰȤƻȤ롣  */
+    定義済みシンボル #Msymbol は <tt>"symbol"</tt> という名前を持ち、関数
+    mchar_define_property () などの引数として使われる。  */
 
 MSymbol Msymbol;
 
@@ -375,18 +375,18 @@ MSymbol Msymbol;
     @errors
     This function never fails.  */
 /***ja
-    @brief ܥ.
+    @brief シンボルを得る.
 
-    ؿ msymbol ()  $NAME 
-    Ȥ̾줿ܥ֤Τ褦ʥܥ뤬¸ߤʤˤϡ롣줿ܥϴǤϤʤ
+    関数 msymbol () は $NAME 
+    という名前を持つ正規化されたシンボルを返す。そのようなシンボルが存在しない場合には、生成する。生成されたシンボルは管理キーではない。
 
-    ʸĤǻϤޤ륷ܥ m17n 饤֥ѤǤꡢŪˤΤѤ롣
+    空白文字二つで始まるシンボルは m17n ライブラリ用であり、内部的にのみ用いられる。
 
     @return
-    δؿϸĤܥ֤
+    この関数は見つけたか生成したかしたシンボルを返す。
 
     @errors
-    δؿϷ褷ƼԤʤ
+    この関数は決して失敗しない。
 
     @latexonly \IPAlabel{msymbol} @endlatexonly  */
 
@@ -436,17 +436,17 @@ msymbol (const char *name)
     If the operation was successful, this function returns the created
     symbol.  Otherwise, it returns #Mnil.  */
 /***ja
-    @brief .
+    @brief 管理キーを作る.
 
-    ؿ msymbol_as_managing_key () ̾ $NAME 
-    Ŀ줿֤Ǥ̾ $NAME ĥܥ뤬С
-    #Mnil ֤
+    関数 msymbol_as_managing_key () は名前 $NAME 
+    を持つ新しく作られた管理キーを返す。すでに名前 $NAME を持つシンボルがあれば、
+    #Mnil を返す。
 
-    ʸĤǻϤޤ륷ܥ m17n 饤֥ѤǤꡢŪˤΤѤ롣
+    空白文字二つで始まるシンボルは m17n ライブラリ用であり、内部的にのみ用いられる。
 
     @return
-    Сδؿܥ֤Ǥʤ
-    #Mnil ֤   */
+    処理に成功すれば、この関数は生成したシンボルを返す。そうでなければ
+    #Mnil を返す。   */
 
 /***
     @errors
@@ -517,16 +517,16 @@ msymbol_is_managing_key (MSymbol symbol)
     @errors
     This function never fails.  */
 /***ja
-    @brief ꤵ줿̾ĥܥõ.
+    @brief 指定された名前を持つシンボルを探す.
 
-    ؿ msymbol_exist ()  $NAME Ȥ̾ĥܥõ
+    関数 msymbol_exist () は $NAME という名前を持つシンボルを探す。
 
     @return
-    ⤷Τ褦ʥܥ뤬¸ߤʤФΥܥ֤ǤʤСѤߥܥ
-    #Mnil ֤  
+    もしそのようなシンボルが存在するならばそのシンボルを返す。そうでなければ、定義済みシンボル
+    #Mnil を返す。  
 
     @errors
-    δؿϷ褷ƼԤʤ     */
+    この関数は決して失敗しない。     */
 
 /***@seealso
     msymbol_name (), msymbol ()  */
@@ -562,13 +562,13 @@ msymbol_exist (const char *name)
     @errors
     This function never fails.  */
 /***ja
-    @brief ܥ̾.
+    @brief シンボルの名前を得る.
 
-    ؿ msymbol_name () ϻꤵ줿ܥ $SYMBOL 
-    ̾ޤʸؤΥݥ󥿤֤
+    関数 msymbol_name () は指定されたシンボル $SYMBOL 
+    の名前を含む文字列へのポインタを返す。
 
     @errors
-    δؿϷ褷ƼԤʤ     */
+    この関数は決して失敗しない。     */
 
 /***@seealso
     msymbol (), msymbol_exist ()  */
@@ -597,18 +597,18 @@ msymbol_name (MSymbol symbol)
     Otherwise it returns -1 and assigns an error code to the external
     variable #merror_code.  */
 /***ja
-    @brief ܥץѥƥͤꤹ.
+    @brief シンボルプロパティに値を設定する.
 
-    ؿ msymbol_put () ϡܥ $SYMBOL ǥ $KEY Ǥ륷ܥץѥƥͤ
-    $VAL ꤹ롣ΥܥץѥƥˤǤͤо񤭤롣
-    $SYMBOL, $KEY Ȥ #Mnil ǤäƤϤʤʤ
+    関数 msymbol_put () は、シンボル $SYMBOL 中でキーが $KEY であるシンボルプロパティの値を
+    $VAL に設定する。そのシンボルプロパティにすでに値があれば上書きする。
+    $SYMBOL, $KEY とも #Mnil であってはならない。
 
-    $KEY ʤС$VAL ϴ֥ȤǤʤƤϤʤʤξ硢Ťͤλȿ
-    @c NULL Ǥʤ 1 餵졢$VAL λȿ 1 䤵롣
+    $KEY が管理キーならば、$VAL は管理下オブジェクトでなくてはならない。この場合、古い値の参照数は
+    @c NULL でなければ 1 減らされ、$VAL の参照数は 1 増やされる。
 
     @return
-    Сmsymbol_put ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    処理が成功すれば、msymbol_put () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -640,16 +640,16 @@ msymbol_put (MSymbol symbol, MSymbol key, void *val)
     If an error is detected, msymbol_get () returns @c NULL and
     assigns an error code to the external variable #merror_code.  */
 /***ja
-    @brief ܥץѥƥͤ.
+    @brief シンボルプロパティの値を得る.
 
-    ؿ msymbol_get () ϡܥ $SYMBOL 
-    ĥܥץѥƥΤ $KEY 
-    ǤΤõ⤷륷ܥץѥƥ¸ߤС֤ͤǤʤ
-    @c NULL ֤
+    関数 msymbol_get () は、シンボル $SYMBOL 
+    が持つシンボルプロパティのうち、キーが $KEY 
+    であるものを探す。もし該当するシンボルプロパティが存在すれば、それの値を返す。そうでなければ
+    @c NULL を返す。
 
     @return 
-    顼Ф줿硢msymbol_get ()  @c NULL 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣  */
+    エラーが検出された場合、msymbol_get () は @c NULL 
+    を返し、外部変数 #merror_code にエラーコードを設定する。  */
 
 /***
     @errors
@@ -679,11 +679,11 @@ msymbol_get (MSymbol symbol, MSymbol key)
     key $KEY.  */
 
 /***ja
-    @brief ܥץѥƥ(ؿݥ)ꤹ.
+    @brief シンボルプロパティの値(関数ポインタ)を設定する.
 
-    ؿ msymbol_put_func () ϡؿ msymbol_put () Ʊͤˡܥ
-    $SYMBOL Υ $KEY Ǥ륷ܥץѥƥͤꤹ롣â
-    ͤϴؿݥ $FUNC Ǥ롣 */
+    関数 msymbol_put_func () は、関数 msymbol_put () と同様に、シンボル
+    $SYMBOL のキーが $KEY であるシンボルプロパティの値を設定する。但し
+    その値は関数ポインタ $FUNC である。 */
 
 /***
     @seealso
@@ -706,11 +706,11 @@ msymbol_put_func (MSymbol symbol, MSymbol key, M17NFunc func)
     getting a function pointer form the property of symbol $SYMBOL.  */
 
 /***ja
-    @brief ܥץѥƥ (ؿݥ) .
+    @brief シンボルプロパティの値 (関数ポインタ) を得る.
 
-    ؿ msymbol_get_func () ϡؿ msymbol_get () Ʊͤˡܥ
-    $SYMBOL ĥܥץѥƥΤ $KEY ǤΤ롣â
-    ͤϴؿݥ󥿤Ǥ롣    */
+    関数 msymbol_get_func () は、関数 msymbol_get () と同様に、シンボル
+    $SYMBOL が持つシンボルプロパティのうち、キーが $KEY であるものを得る。但し
+    その値は関数ポインタをである。    */
 
 /***
     @seealso
@@ -746,14 +746,14 @@ msymbol_get_func (MSymbol symbol, MSymbol key)
     @errors
     MERROR_DEBUG  */
 /***ja
-    @brief ܥפ.
+    @brief シンボルをダンプする.
 
-    ؿ mdebug_dump_symbol () ϥܥ $symbol ɸ२顼Ϥ⤷
-    ϴĶѿ MDEBUG_DUMP_FONT ǻꤵ줿ե˿ʹ֤˲ɤʷ
-    ǰ롣 $INDENT ϣܰʹߤΥǥȤꤹ롣
+    関数 mdebug_dump_symbol () はシンボル $symbol を標準エラー出力もし
+    くは環境変数 MDEBUG_DUMP_FONT で指定されたファイルに人間に可読な形
+    で印刷する。 $INDENT は２行目以降のインデントを指定する。
 
     @return
-    δؿ $SYMBOL ֤ 
+    この関数は $SYMBOL を返す。 
 
     @errors
     MERROR_DEBUG  */
@@ -799,14 +799,14 @@ mdebug_dump_symbol (MSymbol symbol, int indent)
     @errors
     MERROR_DEBUG  */
 /***ja
-    @brief ٤ƤΥܥ̾פ.
+    @brief すべてのシンボル名をダンプする.
 
-    ؿ mdebug_dump_all_symbols () ϡ٤ƤΥܥ̾ɸ२
-    顼Ϥ⤷ϴĶѿ MDEBUG_DUMP_FONT ǻꤵ줿ե˰
-    롣 $INDENT ϣܰʹߤΥǥȤꤹ롣
+    関数 mdebug_dump_all_symbols () は、すべてのシンボルの名前を標準エ
+    ラー出力もしくは環境変数 MDEBUG_DUMP_FONT で指定されたファイルに印
+    刷する。 $INDENT は２行目以降のインデントを指定する。
 
     @return
-    δؿ #Mnil ֤ 
+    この関数は #Mnil を返す。 
 
     @errors
     MERROR_DEBUG  */
@@ -843,6 +843,6 @@ mdebug_dump_all_symbols (int indent)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
