@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nTextProperty
@@ -39,19 +39,19 @@
 
 /***ja
     @addtogroup m17nTextProperty
-    @brief ƥȥץѥƥ뤿δؿ.
+    @brief テキストプロパティを操作するための関数.
 
-    M-text γʸϡ@e ƥȥץѥƥ ȸƤФץѥƥ
-    ĤȤǤ롣ƥȥץѥƥϡM-text γ̤ղä
-    ޤޤʾݻƤꡢץꥱץϤ
-    ξŪ˰ȤǤ롣M-text Τ˭٤ʾĤ
-    ᡢץꥱץδؿǲ뤳ȤǤ롣
+    M-text 内の各文字は、@e テキストプロパティ と呼ばれるプロパティを
+    持つことができる。テキストプロパティは、M-text の各部位に付加され
+    たさまざまな情報を保持しており、アプリケーションプログラムはそれら
+    の情報を統一的に扱うことができる。M-text 自体が豊富な情報を持つた
+    め、アプリケーションプログラム中の関数を簡素化することができる。
 
-    ƥȥץѥƥ @e   @e  ʤ롣ϥܥǤ
-    ꡢͤ <tt>(void *)</tt> ˥㥹ȤǤΤʤ鲿Ǥ褤
-    ¾ΥפΥץѥƥȰۤʤꡢĤΥƥȥץѥƥʣ
-    ĤȤ롣֥ K ǤƥȥץѥƥפΤ
-    ñˡK ץѥƥפȸƤ֤Ȥ롣  */
+    テキストプロパティは @e キー と @e 値 からなる。キーはシンボルであ
+    り、値は <tt>(void *)</tt> 型にキャストできるものなら何でもよい。
+    他のタイプのプロパティと異なり、一つのテキストプロパティが複数の値
+    を持つことが許される。「キーが K であるテキストプロパティ」のこと
+    を簡単に「K プロパティ」と呼ぶことがある。  */
 
 /*=*/
 
@@ -1515,27 +1515,27 @@ mtext__adjust_plist_for_change (MText *mt, int pos, int len1, int len2)
     mtext_get_prop_values () function instead.  */
 
 /***ja
-    @brief ƥȥץѥƥΰ־ͤ.
+    @brief テキストプロパティの一番上の値を得る.
 
-    ؿ mtext_get_prop () ϡM-text $MT ΰ $POS ˤʸΥ
-    ȥץѥƥΤ $KEY ǤΤõ
+    関数 mtext_get_prop () は、M-text $MT 内の位置 $POS にある文字のテ
+    キストプロパティのうち、キーが $KEY であるものを探す。
 
     @return
-    ƥȥץѥƥߤĤСmtext_get_prop () ϤΥץѥƥ
-    ֤ͤͤʣ¸ߤȤϡ־֤ͤĤʤ
-    гѿ #merror_code ѹ뤳Ȥʤ @c NULL ֤
+    テキストプロパティがみつかれば、mtext_get_prop () はそのプロパティ
+    の値を返す。値が複数存在するときは、一番上の値を返す。見つからなけ
+    れば外部変数 #merror_code を変更することなく @c NULL を返す。
 
-    顼Ф줿 mtext_get_prop ()  @c NULL ֤
-     #merror_code ˥顼ɤꤹ롣
+    エラーが検出された場合 mtext_get_prop () は @c NULL を返し、外部変
+    数 #merror_code にエラーコードを設定する。
 
-    @note 顼ʤ @c NULL ֤줿ˤĤβǽ롣
+    @note エラーなしで @c NULL が返された場合には二つの可能性がある。
 
-    @li $POS ΰ֤ʸ $KEY 򥭡Ȥץѥƥʤ
+    @li $POS の位置の文字は $KEY をキーとするプロパティを持たない。
 
-    @li ʸϤΤ褦ʥץѥƥͤ @c NULL Ǥ롣
+    @li その文字はそのようなプロパティを持ち、その値が @c NULL である。
 
-    Ĥ̤ɬפˤϡؿ mtext_get_prop_values ()
-    ˻Ѥ뤳ȡ
+    この二つを区別する必要がある場合には、関数 mtext_get_prop_values ()
+    を代わりに使用すること。
 
      @latexonly \IPAlabel{mtext_get_prop} @endlatexonly  */
 
@@ -1585,18 +1585,18 @@ mtext_get_prop (MText *mt, int pos, MSymbol key)
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ƥȥץѥƥͤʣ.
+    @brief テキストプロパティの値を複数個得る.
 
-    ؿ mtext_get_prop_values () ϡM-text $MT  $POS Ȥ
-    ˤʸΥץѥƥΤ $KEY ǤΤõ⤷
-    Τ褦ʥץѥƥĤС줬 (ʣ)  $VALUES 
-    λؤΰ˳Ǽ롣$NUM ϳǼͤοξ¤Ǥ롣
+    関数 mtext_get_prop_values () は、M-text $MT 内で $POS という位置
+    にある文字のプロパティのうち、キーが $KEY であるものを探す。もしそ
+    のようなプロパティが見つかれば、それが持つ値 (複数可) を $VALUES 
+    の指すメモリ領域に格納する。$NUM は格納する値の数の上限である。
 
     @return
-    Сmtext_get_prop_values () ϼºݤ˥˳Ǽ
-    줿ͤο֤$POS ΰ֤ʸ $KEY 򥭡Ȥץѥƥ
-    ʤ 0 ֤顼Ф줿 -1 ֤
-    ѿ #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば、mtext_get_prop_values () は実際にメモリに格納さ
+    れた値の数を返す。$POS の位置の文字が $KEY をキーとするプロパティ
+    を持たなければ 0 を返す。エラーが検出された場合は -1 を返し、外部
+    変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_get_prop_values} @endlatexonly  */
 
@@ -1663,17 +1663,17 @@ mtext_get_prop_values (MText *mt, int pos, MSymbol key,
 */
 
 /***ja
-    @brief M-text λꤷ֤ΥƥȥץѥƥΥΥꥹȤ.
+    @brief M-text の指定した位置のテキストプロパティのキーのリストを得る.
 
-    ؿ mtext_get_prop_keys () ϡM-text $MT  $POS ΰ֤ˤ
-    ٤ƤΥƥȥץѥƥΥǤȤꡢ
-    ɥ쥹 *$KEYS ꤹ롣Τ˳ݤ줿
-    Τϥ桼ǤǤ롣
+    関数 mtext_get_prop_keys () は、M-text $MT 内で $POS の位置にある
+    すべてのテキストプロパティのキーを要素とする配列を作り、その配列の
+    アドレスを *$KEYS に設定する。この配列のために確保されたメモリを解
+    放するのはユーザの責任である。
 
     @return
-     mtext_get_prop_keys () 줿ꥹȤĹ
-    Ǥʤ -1 ֤ѿ #merror_code ˥顼ɤ
-    ꤹ롣
+    処理が成功すれば mtext_get_prop_keys () は得られたリストの長さを返
+    す。そうでなければ -1 を返し、外部変数 #merror_code にエラーコードを
+    設定する。
 */
 
 /***
@@ -1738,11 +1738,11 @@ PROP  :  <-- OLD_VAL-><-------- VAL -------><-- OLD_VAL-->
     variable #merror_code.  */
 
 /***ja
-    @brief ƥȥץѥƥꤹ.
+    @brief テキストプロパティを設定する.
 
-    ؿ mtext_put_prop () ϡM-text $MT  $FROM ʴޤޤˤ 
-    $TO ʴޤޤʤˤϰϤʸˡ $KEY ͤ $VAL Ǥ
-    ʥƥȥץѥƥꤹ롣δؿˤä
+    関数 mtext_put_prop () は、M-text $MT の $FROM （含まれる）から 
+    $TO （含まれない）の範囲の文字に、キーが $KEY で値が $VAL であるよ
+    うなテキストプロパティを設定する。この関数によって
 
 
 @verbatim
@@ -1751,7 +1751,7 @@ M-text:      |<------------|-------- MT ---------|------------>|
 PROP:         <------------------ OLD_VAL -------------------->
 @endverbatim
 
-ϼΤ褦ˤʤ롣
+は次のようになる。
 
 @verbatim
                          FROM                    TO
@@ -1760,8 +1760,8 @@ PROP:          <-- OLD_VAL-><-------- VAL -------><-- OLD_VAL-->
 @endverbatim
 
     @return
-     mtext_put_prop ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば mtext_put_prop () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_put_prop} @endlatexonly  */
 
@@ -1813,16 +1813,16 @@ mtext_put_prop (MText *mt, int from, int to, MSymbol key, void *val)
     external variable #merror_code.  */
 
 /***ja
-    @brief ƱΥƥȥץѥƥʣꤹ.
+    @brief 同じキーのテキストプロパティを複数設定する.
 
-    ؿ mtext_put_prop_values () ϡM-Text $MT $FROM ʴޤޤ
-     $TO ʴޤޤʤˤϰϤʸˡƥȥץѥƥꤹ
-    롣ƥȥץѥƥΥ $KEY ˤäơ(ʣ) $VALUES 
-    ˤäƻꤵ롣$NUM ꤵͤθĿǤ롣
+    関数 mtext_put_prop_values () は、M-Text $MT の$FROM （含まれる）
+    から $TO （含まれない）の範囲の文字に、テキストプロパティを設定す
+    る。テキストプロパティのキーは $KEY によって、値(複数可)は $VALUES 
+    によって指定される。$NUM は設定される値の個数である。
 
     @return
-    Сmtext_put_prop_values ()  0 ֤Ǥʤ
-     -1 ֤ѿ #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば、mtext_put_prop_values () は 0 を返す。そうでなけ
+    れば -1 を返し、外部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_put_prop_values} @endlatexonly  */
 
@@ -1897,18 +1897,18 @@ PROP  :               <-------- VAL ------->
     variable #merror_code.  */
 
 /***ja
-    @brief ƥȥץѥƥץå夹.
+    @brief テキストプロパティをプッシュする.
 
-    ؿ mtext_push_prop () ϡ $KEY ͤ $VAL Ǥƥ
-    ץѥƥM-text $MT  $FROM ʴޤޤˤ $TO ʴޤޤ
-    ˤϰϤʸ˥ץå夹롣δؿˤä
+    関数 mtext_push_prop () は、キーが $KEY で値が $VAL であるテキスト
+    プロパティを、M-text $MT 中の $FROM （含まれる）から $TO （含まれな
+    い）の範囲の文字にプッシュする。この関数によって
 
 @verbatim
                     FROM                    TO
 M-text: |<------------|-------- MT ---------|------------>|
 PROP  :  <------------------ OLD_VAL -------------------->
 @endverbatim
- ϼΤ褦ˤʤ롣
+ は次のようになる。
 @verbatim 
                     FROM                    TO
 M-text: |<------------|-------- MT ---------|------------>|
@@ -1917,8 +1917,8 @@ PROP  :               <-------- VAL ------->
 @endverbatim
 
     @return
-    Сmtext_push_prop ()  0 ֤Ǥʤ 
-    -1 ֤ѿ #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば、mtext_push_prop () は 0 を返す。そうでなければ 
+    -1 を返し、外部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_push_prop} @endlatexonly  */
 
@@ -2050,21 +2050,21 @@ PROP  :  <--OLD_VAL-->|                     |<--OLD_VAL-->|
     variable #merror_code.  */
 
 /***ja
-    @brief ƥȥץѥƥݥåפ.
+    @brief テキストプロパティをポップする.
 
-    ؿ mtext_pop_prop () ϡ $KEY Ǥƥȥץѥƥ
-    ־ΤΤM-text $MT  $FROM ʴޤޤˤ $TOʴޤ
-    ʤˤϰϤʸ
+    関数 mtext_pop_prop () は、キーが $KEY であるテキストプロパティの
+    うち一番上のものを、M-text $MT の $FROM （含まれる）から $TO（含ま
+    れない）の範囲の文字から取り除く。
 
-    ϰϤʸΤ褦ʥץѥƥʤʤСδؿϲ
-    ⤷ʤδؿˤäơ
+    指定範囲の文字がそのようなプロパティを持たないならば、この関数は何
+    もしない。この関数によって、
 
 @verbatim
                     FROM                    TO
 M-text: |<------------|-------- MT ---------|------------>|
 PROP  :  <------------------ OLD_VAL -------------------->
 @endverbatim
- ϰʲΤ褦ˤʤ롣
+ は以下のようになる。
 @verbatim 
                     FROM                    TO
 M-text: |<------------|-------- MT ---------|------------>|
@@ -2072,8 +2072,8 @@ PROP  :  <--OLD_VAL-->|                     |<--OLD_VAL-->|
 @endverbatim
 
     @return
-    Сmtext_pop_prop ()  0 ֤Ǥʤ -1 
-    ֤ѿ #merror_code ˥顼ɤꤹ롣
+    処理が成功すれば、mtext_pop_prop () は 0 を返す。そうでなければ -1 
+    を返し、外部変数 #merror_code にエラーコードを設定する。
 
     @latexonly \IPAlabel{mtext_pop_prop} @endlatexonly  */
 
@@ -2187,27 +2187,27 @@ mtext_pop_prop (MText *mt, int from, int to, MSymbol key)
     merror_code.  */
 
 /***ja
-    @brief ƥȥץѥƥƱͤȤϰϤĴ٤.
+    @brief テキストプロパティが同じ値をとる範囲を調べる.
 
-    ؿ mtext_prop_range () ϡꤷƥȥץѥƥͤƱ
-    ǤϢ³ʸϰϤĴ٤롣ޤ M-text $MT  $POS ΰ֤
-    ʸΥץѥƥΤ $KEY ǻꤵ줿ͤ򸫤Ĥ
-    롣ʸ $KEY ΥץѥƥͤƱǤ뤫ɤ
-    Ĵ٤롣ĤϰϤκǽȺǸ򡢤줾 $FROM  $TO ˥ݥ
-    Ȥѿ¸롣$FROM ¸ʸΰ֤ϸĤϰ
-    ˴ޤޤ뤬$TO ϴޤޤʤ$TO ƱͤȤϰϤϽ
-    롣ˤϰϻˡϡؿ mtext_put_prop () ʤɤȶ̤Ǥ롣
+    関数 mtext_prop_range () は、指定したテキストプロパティの値が同じ
+    である連続した文字の範囲を調べる。まず M-text $MT の $POS の位置に
+    ある文字のプロパティのうち、キー $KEY で指定されたもの値を見つけ
+    る。そして前後の文字も $KEY のプロパティの値が同じであるかどうかを
+    調べる。見つけた範囲の最初と最後を、それぞれ $FROM と $TO にポイン
+    トされる変数に保存する。$FROM に保存される文字の位置は見つけた範囲
+    に含まれるが、$TO は含まれない。（$TO の前で同じ値をとる範囲は終わ
+    る。）この範囲指定法は、関数 mtext_put_prop () などと共通である。
 
-    $DEEPER  0 ǤʤС$KEY ȤĥץѥƥΤ
-    ΤΤǤʤåΤ٤ƤΤΤӤ롣
+    $DEEPER が 0 でなければ、$KEY というキーを持つプロパティのうち一番
+    上のものだけでなく、スタック中のすべてのものが比較される。
 
-    $FROM  @c NULL ʤСϰϤλϤޤõʤ$TO  @c NULL 
-    ʤСϰϤνõʤ
+    $FROM が @c NULL ならば、範囲の始まりは探索しない。$TO が @c NULL 
+    ならば、範囲の終りは探索しない。
 
     @return
-    Сmtext_prop_range ()  $KEY ץѥƥͤο
-    ֤Ǥʤ-1 ֤ ѿ #merror_code ˥顼
-    ɤꤹ롣
+    処理が成功すれば、mtext_prop_range () は $KEY プロパティの値の数を
+    返す。そうでなければ-1 を返し、 外部変数 #merror_code にエラーコー
+    ドを設定する。
 
     @latexonly \IPAlabel{mtext_prop_range} @endlatexonly  */
 
@@ -2288,14 +2288,14 @@ mtext_prop_range (MText *mt, MSymbol key, int pos,
     MTextPropertyControl.  */
 
 /***ja
-    @brief ƥȥץѥƥ.
+    @brief テキストプロパティを生成する.
 
-    ؿ mtext_property ()  $KEY 򥭡$VAL ͤȤ뿷
-    Ƥ줿ƥȥץѥƥ֤ƥȥץѥƥϤ
-    ʤ M-text ˤղäƤʤʤʬΥ (detached) 롣
+    関数 mtext_property () は $KEY をキー、$VAL を値とする新しく割り当
+    てられたテキストプロパティを返す。生成したテキストプロパティはいか
+    なる M-text にも付加されていない、すなわち分離して (detached) いる。
 
-    $CONTROL_BITS  0 Ǥ뤫 @c enum @c MTextPropertyControl  
-    OR ǤʤƤϤʤʤ  */
+    $CONTROL_BITS は 0 であるか @c enum @c MTextPropertyControl の論理 
+    OR でなくてはならない。  */
 
 MTextProperty *
 mtext_property (MSymbol key, void *val, int control_bits)
@@ -2311,11 +2311,11 @@ mtext_property (MSymbol key, void *val, int control_bits)
     NULL is returned.  */
 
 /***ja
-    @brief ƥȥץѥƥ M-text ֤.
+    @brief あるテキストプロパティを持つ M-text を返す.
 
-    ؿ mtext_property_mtext () ϡƥȥץѥƥ$PROP ղä
-    Ƥ M-text ֤λ $PROP ʬΥƤ NULL 
-    ֤  */
+    関数 mtext_property_mtext () は、テキストプロパティ$PROP が付加さ
+    れている M-text を返す。その時点で $PROP が分離していれば NULL を
+    返す。  */
 
 MText *
 mtext_property_mtext (MTextProperty *prop)
@@ -2330,10 +2330,10 @@ mtext_property_mtext (MTextProperty *prop)
     text property $PROP.  */
 
 /***ja
-    @brief ƥȥץѥƥΥ֤.
+    @brief テキストプロパティのキーを返す.
 
-    ؿ mtext_property_key () ϡƥȥץѥƥ $PROP Υʥ
-    ܥˤ֤  */
+    関数 mtext_property_key () は、テキストプロパティ $PROP のキー（シ
+    ンボル）を返す。  */
 
 MSymbol
 mtext_property_key (MTextProperty *prop)
@@ -2348,10 +2348,10 @@ mtext_property_key (MTextProperty *prop)
     property $PROP.  */
 
 /***ja
-    @brief ƥȥץѥƥ֤ͤ.
+    @brief テキストプロパティの値を返す.
 
-    ؿ mtext_property_value () ϡƥȥץѥƥ $PROP ͤ
-      */
+    関数 mtext_property_value () は、テキストプロパティ $PROP の値を返
+    す。  */
 
 void *
 mtext_property_value (MTextProperty *prop)
@@ -2368,11 +2368,11 @@ mtext_property_value (MTextProperty *prop)
     -1.  */
 
 /***ja
-    @brief ƥȥץѥƥγϰ֤֤.
+    @brief テキストプロパティの開始位置を返す.
 
-    ؿ mtext_property_start () ϡƥȥץѥƥ $PROP γϰ
-    ֤֤ϰ֤Ȥ M-text  $PROP Ϥޤʸ֤Ǥ롣
-    $PROP ʬΥƤС-1 ֤  */
+    関数 mtext_property_start () は、テキストプロパティ $PROP の開始位
+    置を返す。開始位置とは M-text 中で $PROP が始まる文字位置である。
+    $PROP が分離されていれば、-1 を返す。  */
 
 int
 mtext_property_start (MTextProperty *prop)
@@ -2389,11 +2389,11 @@ mtext_property_start (MTextProperty *prop)
     -1.  */
 
 /***ja
-    @brief ƥȥץѥƥνλ֤֤.
+    @brief テキストプロパティの終了位置を返す.
 
-    ؿ mtext_property_end () ϡƥȥץѥƥ $PROP νλ
-    ֤λ֤Ȥ M-text  $PROP ʸ֤Ǥ롣$PROP 
-    ʬΥƤС-1 ֤  */
+    関数 mtext_property_end () は、テキストプロパティ $PROP の終了位置
+    を返す。終了位置とは M-text 中で $PROP が終る文字位置である。$PROP 
+    が分離されていれば、-1 を返す。  */
 
 int
 mtext_property_end (MTextProperty *prop)
@@ -2417,18 +2417,18 @@ mtext_property_end (MTextProperty *prop)
     assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ־Υƥȥץѥƥ.
+    @brief 一番上のテキストプロパティを得る.
 
-    ؿ mtext_get_property ()  M-text $MT ΰ $POS ʸ
-     $KEY ǤƥȥץѥƥĤɤĴ٤롣
+    関数 mtext_get_property () は M-text $MT の位置 $POS の文字がキー
+    が $KEY であるテキストプロパティを持つかどうかを調べる。
 
     @return 
-    ƥȥץѥƥĤСmtext_get_property () Ϥ֤
-    ʣˤϡ־ΤΤ֤ĤʤСѿ 
-    #merror_code Ѥ뤳Ȥʤ @c NULL ֤
+    テキストプロパティが見つかれば、mtext_get_property () はそれを返す。
+    複数ある場合には、一番上のものを返す。見つからなければ、外部変数 
+    #merror_code を変えることなく @c NULL を返す。
 
-    顼Ф줿 mtext_get_property ()  @c NULL ֤
-    ѿ #merror_code ˥顼ɤꤹ롣    */
+    エラーが検出された場合 mtext_get_property () は @c NULL を返し、外
+    部変数 #merror_code にエラーコードを設定する。    */
 
 MTextProperty *
 mtext_get_property (MText *mt, int pos, MSymbol key)
@@ -2465,19 +2465,19 @@ mtext_get_property (MText *mt, int pos, MSymbol key)
     and assigns an error code to the external variable #merror_code.  */
 
 /***ja
-    @brief ʣΥƥȥץѥƥ.
+    @brief 複数のテキストプロパティを得る.
 
-    ؿ mtext_get_properties ()  M-text $MT ΰ $POS ʸ
-     $KEY ǤƥȥץѥƥĤɤĴ٤롣Τ褦
-    ץѥƥߤĤС$PROPS ؤΰ¸롣$NUM 
-    ¸ץѥƥοξ¤Ǥ롣
+    関数 mtext_get_properties () は M-text $MT の位置 $POS の文字がキー
+    が $KEY であるテキストプロパティを持つかどうかを調べる。そのような
+    プロパティがみつかれば、$PROPS が指すメモリ領域に保存する。$NUM は
+    保存されるプロパティの数の上限である。
 
     @return 
-    Сmtext_get_properties () ϼºݤ¸ץѥƥ
-    ο֤$POS ΰ֤ʸ $KEY Ǥץѥƥ
-    ʤС0 ֤롣顼Ф줿ˤϡ
-    mtext_get_properties ()  -1 ֤ѿ #merror_code ˥顼
-    ɤꤹ롣  */
+    処理が成功すれば、mtext_get_properties () は実際に保存したプロパティ
+    の数を返す。$POS の位置の文字がキーが $KEY であるプロパティを持た
+    なければ、0 が返る。エラーが検出された場合には、
+    mtext_get_properties () は -1 を返し、外部変数 #merror_code にエラー
+    コードを設定する。  */
 
 int
 mtext_get_properties (MText *mt, int pos, MSymbol key,
@@ -2529,15 +2529,15 @@ mtext_get_properties (MText *mt, int pos, MSymbol key,
     external variable #merror_code.  */
 
 /***ja
-    @brief  M-text˥ƥȥץѥƥղä.
+    @brief  M-textにテキストプロパティを付加する.
 
-    ؿ mtext_attach_property () ϡM-text $MT  $FROM  $TO 
-    Ǥΰ˥ƥȥץѥƥ $PROP ղä롣⤷ $PROP 
-    M-text ղäƤС$MT ղäʬΥ롣
+    関数 mtext_attach_property () は、M-text $MT の $FROM から $TO ま
+    での領域にテキストプロパティ $PROP を付加する。もし $PROP が既に
+    M-text に付加されていれば、$MT に付加する前に分離される。
 
     @return 
-    Сmtext_attach_property ()  0 ֤Ǥʤ
-     -1 ֤Ƴѿ#merror_code ˥顼ɤꤹ롣      */
+    処理に成功すれば、mtext_attach_property () は 0 を返す。そうでなけ
+    れば -1 を返して外部変数#merror_code にエラーコードを設定する。      */
 
 
 int
@@ -2580,12 +2580,12 @@ mtext_attach_property (MText *mt, int from, int to, MTextProperty *prop)
     This function always returns 0.  */
 
 /***ja
-    @brief  M-text ƥȥץѥƥʬΥ.
+    @brief  M-text からテキストプロパティを分離する.
 
-    ؿ mtext_detach_property () ϥƥȥץѥƥ $PROP ʬΥ롣
+    関数 mtext_detach_property () はテキストプロパティ $PROP を分離する。
 
     @return
-    δؿϾ 0 ֤  */
+    この関数は常に 0 を返す。  */
 
 int
 mtext_detach_property (MTextProperty *prop)
@@ -2615,15 +2615,15 @@ mtext_detach_property (MTextProperty *prop)
     external variable #merror_code.  */
 
 /***ja
-    @brief M-text ˥ƥȥץѥƥץå夹.
+    @brief M-text にテキストプロパティをプッシュする.
 
-    ؿ mtext_push_property () ϡƥȥץѥƥ $PROP 
-    M-text $MT  $FROM ʴޤޤˤ $TO ʴޤޤʤˤϰϤ
-    ʸ˥ץå夹롣
+    関数 mtext_push_property () は、テキストプロパティ $PROP を、
+    M-text $MT 中の $FROM （含まれる）から $TO （含まれない）の範囲の
+    文字にプッシュする。
 
     @return
-    Сmtext_push_property ()  0 ֤Ǥʤ
-     -1 ֤Ƴѿ#merror_code ˥顼ɤꤹ롣      */
+    処理に成功すれば、mtext_push_property () は 0 を返す。そうでなけ
+    れば -1 を返して外部変数#merror_code にエラーコードを設定する。      */
 
 
 int
@@ -2727,12 +2727,12 @@ mtext_push_property (MText *mt, int from, int to, MTextProperty *prop)
   */
 
 /***ja
-    @brief ꥢ饤ؿꤹ륷ܥ.
+    @brief シリアライザ関数を指定するシンボル.
 
-    ƥȥץѥƥ򥷥ꥢ饤뤿ˤϡΥƥȥץ
-    ƥѤΥꥢ饤ؿͿʤƤϤʤʤŪˤϡ
-    #Mtext_prop_serializer 򥭡ȤŬڤʥꥢ饤ؿؤΥݥ
-    󥿤ͤȤ륷ܥץѥƥꤹ롣
+    テキストプロパティをシリアライズするためには、そのテキストプロパ
+    ティ用のシリアライザ関数を与えなくてはならない。具体的には、
+    #Mtext_prop_serializer をキーとし、適切なシリアライズ関数へのポイ
+    ンタを値とするシンボルプロパティを指定する。
 
     @seealso
     mtext_serialize (), #MTextPropSerializeFunc
@@ -2752,12 +2752,12 @@ MSymbol Mtext_prop_serializer;
   */
 
 /***ja
-    @brief ǥꥢ饤ؿꤹ륷ܥ.
+    @brief デシリアライザ関数を指定するシンボル.
 
-    ƥȥץѥƥǥꥢ饤뤿ˤϡΥƥȥץ
-    ѥƥѤΥǥꥢ饤ؿͿʤƤϤʤʤŪˤϡ
-    #Mtext_prop_deserializer 򥭡ȤŬڤʥǥꥢ饤ؿؤ
-    ݥ󥿤ͤȤ륷ܥץѥƥꤹ롣
+    テキストプロパティをデシリアライズするためには、そのテキストプロ
+    パティ用のデシリアライザ関数を与えなくてはならない。具体的には、
+    #Mtext_prop_deserializer をキーとし、適切なデシリアライズ関数への
+    ポインタを値とするシンボルプロパティを指定する。
 
     @seealso
     mtext_deserialize (), #MTextPropSerializeFunc
@@ -2805,20 +2805,20 @@ MSymbol Mtext_prop_deserializer;
     mtext_deserialize (), #Mtext_prop_serializer  */
 
 /***ja
-    @brief M-text Υƥȥץѥƥ򥷥ꥢ饤.
+    @brief M-text 中のテキストプロパティをシリアライズする.
 
-    ؿ mtext_serialize ()  M-text $MT  $FROM  $TO ޤǤΥƥ
-    Ȥ򥷥ꥢ饤롣ꥢ饤̤ XML  M-text 
-    롣 $PROPERTY_LIST ϥꥢ饤ƥȥץѥƥ
-    롣оݤȤʤƥȥץѥƥϡΥ
+    関数 mtext_serialize () は M-text $MT の $FROM から $TO までのテキ
+    ストをシリアライズする。シリアライズした結果は XML 形式の M-text で
+    ある。 $PROPERTY_LIST はシリアライズされるテキストプロパティを限定
+    する。対象となるテキストプロパティは、そのキーが
 
-    @li $PROPERTY_LIST ǤͤȤƸ졢
-    @li ܥץѥƥ #Mtext_prop_serializer 
+    @li $PROPERTY_LIST の要素の値として現われ、かつ
+    @li シンボルプロパティ #Mtext_prop_serializer を持つ
     
-    ΤΤߤǤ롣ξƥȥץѥƥϡ 
-    XML ɽ "property" Ǥ˥ꥢ饤롣
+    もののみである。この条件を満たすテキストプロパティは、生成される 
+    XML 表現中で "property" 要素にシリアライズされる。
 
-     XML  DTD ϰʲ̤:
+    生成される XML の DTD は以下の通り:
 
 @verbatim
 <!DOCTYPE mtext [
@@ -2833,13 +2833,13 @@ MSymbol Mtext_prop_deserializer;
  ]>
 @endverbatim
 
-    δؿ libxml2 饤֥˰¸롣m17n 饤֥꤬libxml2 
-    ̵ꤵƤ硢δؿϾ˼Ԥ롣
+    この関数は libxml2 ライブラリに依存する。m17n ライブラリがlibxml2 
+    無しに設定されている場合、この関数は常に失敗する。
 
     @return 
-    Сmtext_serialize ()  XML  M-text ֤
-    Ǥʤ @c NULL ֤Ƴѿ#merror_code ˥顼
-    ꤹ롣
+    処理に成功すれば、mtext_serialize () は XML 形式で M-text を返す。
+    そうでなければ @c NULL を返して外部変数#merror_code にエラーコード
+    を設定する。
 
     @seealso
     mtext_deserialize (), #Mtext_prop_serializer  */
@@ -2964,10 +2964,10 @@ mtext_serialize (MText *mt, int from, int to, MPlist *property_list)
     mtext_serialize (), #Mtext_prop_deserializer  */
 
 /***ja
-    @brief M-text Υƥȥץѥƥǥꥢ饤.
+    @brief M-text 中のテキストプロパティをデシリアライズする.
 
-    ؿ mtext_deserialize ()  M-text $MT ǥꥢ饤롣$MT
-    ϼ DTD  XML ǤʤƤϤʤʤ
+    関数 mtext_deserialize () は M-text $MT をデシリアライズする。$MT
+    は次の DTD を持つ XML でなくてはならない。
  
 @verbatim
 <!DOCTYPE mtext [
@@ -2982,13 +2982,13 @@ mtext_serialize (MText *mt, int from, int to, MPlist *property_list)
  ]>
 @endverbatim
 
-    δؿ libxml2 饤֥˰¸롣m17n 饤֥꤬libxml2 
-    ̵ꤵƤ硢δؿϾ˼Ԥ롣
+    この関数は libxml2 ライブラリに依存する。m17n ライブラリがlibxml2 
+    無しに設定されている場合、この関数は常に失敗する。
 
     @return 
-    Сmtext_serialize () 줿 M-text 
-    ֤Ǥʤ @c NULL ֤Ƴѿ #merror_code ˥顼
-    ɤꤹ롣
+    処理に成功すれば、mtext_serialize () は得られた M-text を
+    返す。そうでなければ @c NULL を返して外部変数 #merror_code にエラー
+    コードを設定する。
 
     @seealso
     mtext_serialize (), #Mtext_prop_deserializer  */
@@ -3107,6 +3107,6 @@ mtext_deserialize (MText *mt)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
